==> ser-0.8.10_src.tar.gz: ser-0.8.10/parser/case_max.h <==
/*
 * $Id: case_max.h,v 1.3 2002/09/19 12:23:55 jku Rel $
 *
 * Max-Forwards header field parser macros
 *
 * Copyright (C) 2001-2003 Fhg Fokus
 *
 * This file is part of ser, a free SIP server.
 *
 * ser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * ser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef CASE_MAX_H
#define CASE_MAX_H


#define ARDS_CASE                            \
        if (val == _ards_) {                 \
	        hdr->type = HDR_MAXFORWARDS; \
	        p += 4;                      \
		goto dc_end;                 \
	}


#define FORW_CASE                 \
        switch(val) {             \
        case _Forw_:              \
	        p += 4;           \
	        val = READ(p);    \
                ARDS_CASE;        \
                                  \
	        val = unify(val); \
		ARDS_CASE;        \
	        goto other;       \
        }                                             


#define Max_CASE       \
     p += 4;           \
     val = READ(p);    \
     FORW_CASE;        \
                       \
     val = unify(val); \
     FORW_CASE;        \
     goto other;       \


#endif /* CASE_MAX_H */

==> ser-0.8.14_src.tar.gz: ser-0.8.14/parser/case_max.h <==
/* 
 * $Id: case_max.h,v 1.4 2002/11/18 19:08:16 janakj Exp $ 
 *
 * Max-Forwards Header Field Name Parsing Macros
 *
 * Copyright (C) 2001-2003 Fhg Fokus
 *
 * This file is part of ser, a free SIP server.
 *
 * ser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * ser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef CASE_MAX_H
#define CASE_MAX_H


#define ARDS_CASE                            \
        if (LOWER_DWORD(val) == _ards_) {    \
	        hdr->type = HDR_MAXFORWARDS; \
	        p += 4;                      \
		goto dc_end;                 \
	}


#define FORW_CASE                  \
        switch(LOWER_DWORD(val)) { \
        case _forw_:               \
	        p += 4;            \
	        val = READ(p);     \
                ARDS_CASE;         \
	        goto other;        \
        }                                             


#define max_CASE       \
     p += 4;           \
     val = READ(p);    \
     FORW_CASE;        \
     goto other;       \


#endif /* CASE_MAX_H */
